==> bookmarkbridge_0.72.orig.tar.gz: bookmarkbridge-0.72/bookmarkbridge/xbelwrite.h <==
/***************************************************************************
                      xbelwrite.h  -  XbelWrite Definition
                             -------------------
    begin                : Sun Sep 15 2002
    copyright            : (C) 2002 by Ken Schenke
    email                : kenschenke at yahoo dot com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   In addition, as a special exception, Ken Schenke gives permission to  *
 *   link the code of this program with the Qt non-commercial edition (or  *
 *   with modified versions of the Qt non-commercial edition that use the  *
 *   same license as the Qt non-commercial edition, and distribute linked  *
 *   combinations including the two.  You must obey the GNU General Public *
 *   License in all respects for all of the code used other than the Qt    *
 *   Non-Commercial edition.  If you modify this file, you may extend this *
 *   exception to your version of the file, but you are not obligated to   *
 *   do so.  If you do not wish to do so, delete this exception statement  *
 *   from your version.                                                    *
 *                                                                         *
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This function writes an XBEL (XML) bookmark file.                     *
 *                                                                         *
 ***************************************************************************/

#ifndef XBELWRITE_H
#define XBELWRITE_H

#include "bknode.h"
#include "bridgecfg.h"
#include "bkexcept.h"

#include <qtextstream.h>
#include <time.h>

void	WriteDate(QTextStream &stream, time_t t);
void	WriteXbelDocument(const char *filename, const BkFolder &Root, BridgeCfg &cfg)
			throw(BkException);

#endif // end of XBELWRITE_H

==> bookmarkbridge_0.76.orig.tar.gz: bookmarkbridge-0.76/bookmarkbridge/xbelwrite.h <==
/***************************************************************************
                      xbelwrite.h  -  XbelWrite Definition
                             -------------------
    begin                : Sun Sep 15 2002
    copyright            : (C) 2002 by Ken Schenke
    email                : kschenke at users dot sourceforge dot net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful, but   *
 *   WITHOUT ANY WARRANTY; without even the implied warranty of            *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      *
 *   General Public License for more details.                              *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the Free Software           *
 *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA         *
 *   02110-1301, USA                                                       *
 *                                                                         *
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This function writes an XBEL (XML) bookmark file.                     *
 *                                                                         *
 ***************************************************************************/

#ifndef XBELWRITE_H
#define XBELWRITE_H

#include "bknode.h"
#include "bridgecfg.h"
#include "bkexcept.h"

#include <QTextStream>
#include <time.h>

void	WriteDate(QTextStream &stream, time_t t);
void	WriteXbelDocument(const QString &filename, const BkFolder &Root, BridgeCfg &cfg)
			throw(BkException);

#endif // end of XBELWRITE_H
